@@ -15,6 +15,9 @@ Loads JSON files. Example:
         "name": "TestApp",
         "Controller::Foo": {
             "foo": "bar"
+        },
+        "Model::Baz": {
+            "qux": "xyzzy"
         }
     }
 
