@@ -13,8 +13,11 @@ Loads Perl files. Example:
 
     {
         name => 'TestApp',
-        Controller::Foo => {
+        'Controller::Foo' => {
             foo => 'bar'
+        },
+        'Model::Baz' => {
+            qux => 'xyzzy'
         }
     }
 
